Stan Math Library: stan/math/prim/arr/meta/get.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

get.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_ARR_META_GET_HPP
2 #define STAN_MATH_PRIM_ARR_META_GET_HPP
3
4 #include <cstdlib>
5 #include <vector>
6
7 namespace stan {
8
9 template <typename T>
10 inline T get(const std::vector<T>& x, size_t n) {
11 return x[n];
12 }
13
14 }
15 #endif
16
stan
Definition: log_sum_exp.hpp:8

[ Stan Home Page ] © 2011–2016, Stan Development Team.